function S = ConstructScaling(sx, sy, sz)
  % -----------------------------------------------------------------------
  % ConstructScaling - Construct the transformation matrix that scales 
  %                    by sx, sy and sz.
  %
  % Args: sx - scalar giving the x scale factor
  %       sy - scalar giving the y scale factor
  %       sz - scalar giving the z scale factor
  %
  % Rtns: S - the 4 x 4 matrix of the transformation
  % -----------------------------------------------------------------------

  S = [
   sx   0   0   0
    0  sy   0   0
    0   0  sz   0
    0   0   0   1
  ];
end
